summaryrefslogtreecommitdiffstats
path: root/node-admin/src/main
diff options
context:
space:
mode:
authorValerij Fredriksen <valerijf@oath.com>2018-05-29 15:05:42 +0200
committerValerij Fredriksen <valerijf@oath.com>2018-05-29 15:05:42 +0200
commitf1fd27cae660cacb79ee820a94f67957366b6c5d (patch)
tree62ea8690844cf71551d31eff704761a2eccedb88 /node-admin/src/main
parent1276d843f6fb1acbe3b78126203ecadcfa5cf8df (diff)
suspendConverge() -> convergeSuspend()
Diffstat (limited to 'node-admin/src/main')
-rw-r--r--node-admin/src/main/java/com/yahoo/vespa/hosted/node/admin/component/IdempotentTask.java8
1 files changed, 4 insertions, 4 deletions
diff --git a/node-admin/src/main/java/com/yahoo/vespa/hosted/node/admin/component/IdempotentTask.java b/node-admin/src/main/java/com/yahoo/vespa/hosted/node/admin/component/IdempotentTask.java
index 14f94d5b373..71e55c36284 100644
--- a/node-admin/src/main/java/com/yahoo/vespa/hosted/node/admin/component/IdempotentTask.java
+++ b/node-admin/src/main/java/com/yahoo/vespa/hosted/node/admin/component/IdempotentTask.java
@@ -46,16 +46,16 @@ public interface IdempotentTask<T extends TaskContext> {
* TaskContext should provide enough to determine what kind of suspend is wanted, e.g.
* suspension of only the task, or the task and the resources/processes it manages.</p>
*
* <p>suspendConverge() must be idempotent: it may be called any number of times, or
* interrupted at any time e.g. by `kill -9`.</p>
*
* <p>suspendConverge() is not thread safe: The caller must ensure there is at most one
* invocation of suspendConverge() at any given time.</p>
*
* @return false if already converged, i.e. was a no-op
* @throws RuntimeException (or a subclass) if the task is unable to suspend.
*/
- default boolean suspendConverge(T context) {
+ default boolean convergeSuspend(T context) {
return false;
}
}
@@ -46,16 +46,16 @@ public interface IdempotentTask<T extends TaskContext> {
* suspension of only the task, or the task and the resources/processes it manages.</p>
*
- * <p>suspendConverge() must be idempotent: it may be called any number of times, or
+ * <p>convergeSuspend() must be idempotent: it may be called any number of times, or
* interrupted at any time e.g. by `kill -9`.</p>
*
@@ -46,16 +46,16 @@ public interface IdempotentTask<T extends TaskContext> {
* interrupted at any time e.g. by `kill -9`.</p>
*
- * <p>suspendConverge() is not thread safe: The caller must ensure there is at most one
- * invocation of suspendConverge() at any given time.</p>
+ * <p>convergeSuspend() is not thread safe: The caller must ensure there is at most one
+ * invocation of convergeSuspend() at any given time.</p>
*
* @return false if already converged, i.e. was a no-op